# Generated by Django 4.0.5 on 2022-06-29 23:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("enhanced_curation", "0005_documentcache_top25percent"),
    ]

    operations = [
        migrations.AddField(
            model_name="documentcache",
            name="has_achievement_level",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="documentcache",
            name="top1percent",
            field=models.BooleanField(default=False),
        ),
    ]
