# Generated by Django 4.0.5 on 2022-06-22 18:11

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("enhanced_curation", "0003_alter_collectioncache_last_run"),
    ]

    operations = [
        migrations.AddField(
            model_name="documentcache",
            name="priority_populations",
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.TextField(), default=list, size=None
            ),
        ),
        migrations.AddField(
            model_name="documentcache",
            name="subject",
            field=models.TextField(null=True),
        ),
        migrations.AddField(
            model_name="documentcache",
            name="work_locations",
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.TextField(), default=list, size=None
            ),
        ),
    ]
