# Generated by Django 4.0.5 on 2022-06-22 13:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("enhanced_curation", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="documentcache",
            name="org_budget",
            field=models.TextField(null=True),
        ),
        migrations.AlterField(
            model_name="documentcache",
            name="org_size",
            field=models.TextField(null=True),
        ),
    ]
