# Generated by Django 4.0.5 on 2022-06-29 16:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("enhanced_curation", "0004_documentcache_priority_populations_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="documentcache",
            name="top25percent",
            field=models.BooleanField(default=False),
        ),
    ]
