# Generated by Django 4.0.5 on 2022-06-22 13:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("enhanced_curation", "0002_alter_documentcache_org_budget_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="collectioncache",
            name="last_run",
            field=models.DateTimeField(null=True),
        ),
    ]
