# Generated by Django 4.0.5 on 2022-06-22 12:44

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("torque", "0040_value_unique_value_for_field_document"),
    ]

    operations = [
        migrations.CreateModel(
            name="CollectionCache",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_run", models.DateTimeField()),
                (
                    "collection",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="torque.collection",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="DocumentCache",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("org_size", models.TextField()),
                ("org_budget", models.TextField()),
                ("org_name", models.TextField()),
                (
                    "collection_cache",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="documents",
                        to="enhanced_curation.collectioncache",
                    ),
                ),
                (
                    "document",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="torque.document",
                    ),
                ),
            ],
        ),
    ]
